==> gspiceui_0.9.55.dfsg.orig.tar.gz: gspiceui-0.9.55.dfsg/src/ngspice/commands/CmdNgSpiceAC.hpp <==
//*****************************************************************************
//                              CmdNgSpiceAC.hpp                              *
//                             ------------------                             *
//  Description : This class contains values associated with the NG-Spice     *
//                AC command. It inherits from the class CmdBase.             *
//  Started     : 11/10/2007                                                  *
//  Last Update : 15/10/2007                                                  *
//  Copyright   : (C) 2007 by M.S.Waters                                      *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef CMDNGSPICEAC_HPP
#define CMDNGSPICEAC_HPP

// System Includes

#include <iostream>
#include <climits>

// wxWidgets Includes

#include <wx/wx.h>
#include <wx/tokenzr.h>

// Application Includes

#include "TypeDefs.hpp"
#include "base/CmdBase.hpp"
#include "utility/ConvertType.hpp"

// Local Macro and Constant Declarations

//*****************************************************************************

class CmdNgSpiceAC : public CmdBase
{
  protected:

    virtual  bool  bParse ( void );
    virtual  bool  bFormat( void );

  public:

    float       m_fStart;  // The sweep start value
    float       m_fStop;   // The sweep stop  value
    int         m_iStep;   // The sweep step  value
    eScaleType  m_eScale;  // The sweep scale type

              CmdNgSpiceAC( void );
    virtual  ~CmdNgSpiceAC( );

    bool  bClear( void );
};

//*****************************************************************************

#endif // CMDNGSPICEAC_HPP

==> gspiceui_0.9.65.dfsg.orig.tar.gz: gspiceui-0.9.65.dfsg/src/ngspice/commands/CmdNgSpiceAC.hpp <==
//*****************************************************************************
//                              CmdNgSpiceAC.hpp                              *
//                             ------------------                             *
//  Description : This class contains values associated with the NG-Spice     *
//                AC command. It inherits from the class CmdBase.             *
//  Started     : 11/10/2007                                                  *
//  Last Update : 11/12/2007                                                  *
//  Copyright   : (C) 2007 by M.S.Waters                                      *
//  Email       : M.Waters@bom.gov.au                                         *
//*****************************************************************************

//*****************************************************************************
//                                                                            *
//    This program is free software; you can redistribute it and/or modify    *
//    it under the terms of the GNU General Public License as published by    *
//    the Free Software Foundation; either version 2 of the License, or       *
//    (at your option) any later version.                                     *
//                                                                            *
//*****************************************************************************

#ifndef CMDNGSPICEAC_HPP
#define CMDNGSPICEAC_HPP

// System Includes

#include <iostream>
#include <climits>

// wxWidgets Includes

#include <wx/wx.h>
#include <wx/tokenzr.h>

// Application Includes

#include "TypeDefs.hpp"
#include "base/CmdBase.hpp"
#include "utility/ConvertType.hpp"

// Local Macro and Constant Declarations

//*****************************************************************************

struct CmdNgSpiceAC : public CmdBase
{
  public :

    float       m_fStart;  // The sweep start value
    float       m_fStop;   // The sweep stop  value
    float       m_fStep;   // The sweep step  value
    eScaleType  m_eScale;  // The sweep scale type

              CmdNgSpiceAC( void );
    virtual  ~CmdNgSpiceAC( );

    bool  bClear( void );

    virtual  bool  bParse ( void );
    virtual  bool  bFormat( void );

    wxString & operator = ( const wxString & ros )
                { *((wxString *) this) = ros; return( *((wxString *) this) ); }
};

//*****************************************************************************

#endif // CMDNGSPICEAC_HPP
